@@ -1,8 +1,8 @@
 #include <torch/extension.h>
 
 
-torch::Tensor discounted_cumsum_left_cuda(torch::Tensor x, double gamma);
-torch::Tensor discounted_cumsum_right_cuda(torch::Tensor x, double gamma);
+torch::Tensor discounted_cumsum_left_cuda(torch::Tensor x, torch::Tensor gamma);
+torch::Tensor discounted_cumsum_right_cuda(torch::Tensor x, torch::Tensor gamma);
 
 
 PYBIND11_MODULE(TORCH_EXTENSION_NAME, m) {
